@@ -32,6 +32,7 @@ def default_cache_func(
 
 
 def cache_to_django(django_model, redis_dicts, redis_root):
+
     async def run_cache_to_django(django_model, redis_dicts, redis_root):
         async_chunk_size = redis_root.async_db_requests_limit
         async_tasks = []
@@ -39,7 +40,6 @@ def cache_to_django(django_model, redis_dicts, redis_root):
         to_complete = len(redis_dicts.keys())
 
         for redis_instance_id, redis_instance_data in redis_dicts.items():
-            print(redis_instance_data)
             async_tasks.append(
                 update_or_create_django_instance_from_redis_instance(
                     redis_instance_data,
@@ -50,8 +50,7 @@ def cache_to_django(django_model, redis_dicts, redis_root):
             if len(async_tasks) == async_chunk_size or completed == to_complete:
                 await asyncio.gather(*async_tasks)
                 async_tasks = []
-                print(
-                    f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
+                print(f'{datetime.datetime.now()} - Written {completed} {django_model.__name__} instances from cache to django')
 
     loop = asyncio.get_event_loop()
     loop.run_until_complete(run_cache_to_django(django_model, redis_dicts, redis_root))
@@ -96,7 +95,8 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
     django_instance = None
 
     if need_to_create:
-        print(need_to_create, django_params, django_many_to_many_params)
+        pass
+    #     print(need_to_create, django_params, django_many_to_many_params)
     #     django_instance = django_model.objects.create(**django_params)
     #     update_django_many_to_many(
     #         django_model,
@@ -115,7 +115,7 @@ def sync_to_async_update_or_create_django_instance_from_redis_instance(
             django_instance_fields_value = getattr(django_instance, redis_field_name)
             if django_instance_fields_value != redis_field_value:
                 changed_many_to_many_fields_to_update[redis_field_name] = redis_field_value
-        print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
+    #     print(need_to_create, changed_fields_to_update, changed_many_to_many_fields_to_update)
     #     django_model.objects.filter(id=django_id).update(**changed_fields_to_update)
     #     update_django_many_to_many(
     #         django_model,
@@ -140,24 +140,24 @@ async def async_redis_dict_to_django_params(
             if django_field_data['class'] == django_models.ForeignKey:
                 foreign_key_model = django_field_data['remote_field_model']
                 redis_foreign_key_instance = redis_dict[django_field_name]
+                print(django_field_name, redis_foreign_key_instance)
                 print('foreign_key', redis_foreign_key_instance)
                 django_foreign_key_instance = await update_or_create_django_instance_from_redis_instance(
                     redis_foreign_key_instance,
-                    foreign_key_model
+                    foreign_key_model,
                 )
                 django_params[django_field_name] = django_foreign_key_instance
             elif django_field_data['class'] == django_models.ManyToManyField:
                 many_to_many_model = django_field_data['remote_field_model']
                 django_many_to_many_instances = []
                 redis_many_to_many_instances = redis_dict[django_field_data['name']]
-                for redis_many_to_many_instance in redis_many_to_many_instances:
-
-                    print('many_to_many ', redis_many_to_many_instance)
-                    django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
-                        redis_many_to_many_instance,
-                        many_to_many_model
-                    )
-                    django_many_to_many_instances.append(django_many_to_many_instance)
+                if redis_many_to_many_instances != 'null':
+                    for redis_many_to_many_instance in redis_many_to_many_instances:
+                        django_many_to_many_instance = await update_or_create_django_instance_from_redis_instance(
+                            redis_many_to_many_instance,
+                            many_to_many_model,
+                        )
+                        django_many_to_many_instances.append(django_many_to_many_instance)
                 django_many_to_many_params[django_field_name] = django_many_to_many_instances
             else:
                 value = redis_dict[django_field_data['name']]
