@@ -143,11 +143,9 @@ class RedisForeignKey(RedisNumber):
                 if 'id' in self.value.keys():
                     self.value = self.value['id']
                 else:
-                    raise Exception(
-                        f"{self.value} has no key 'id', please provide serialized instance or dict like " + "{'id': 1, ...}")
+                    raise Exception(f"{self.value} has no key 'id', please provide serialized instance or dict like " + "{'id': 1, ...}")
             else:
-                raise Exception(
-                    f'{self.value} type is not dict, please provide serialized instance or dict like ' + "{'id': 1, ...}")
+                raise Exception(f'{self.value} type is not dict, please provide serialized instance or dict like ' + "{'id': 1, ...}")
         return self.value
 
     def clean(self):
@@ -157,31 +155,14 @@ class RedisForeignKey(RedisNumber):
             self.value = get_ids_from_untyped_data(self.value)[0]
         return super().clean()
 
-    def _get_instance_by_id(self, id, redis_root):
-        model_name = self.model.__name__
-        instance = {
-            'id': id
-        }
-        fast_get_results = redis_root.fast_get_keys_values(f'{redis_root.prefix}:{model_name}:{id}:*')
-        for key, raw_value in fast_get_results.items():
-            prefix, model_name, instance_id, field_name = key.split(':')
-            value = redis_root.deserialize_value(raw_value, model_name, field_name)
-            instance[field_name] = value
-        return instance
-
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
             check_types(value, int)
-            if self.save_related_models:
-                print(value, self._get_instance_by_id(value, redis_root))
-                value = self._get_instance_by_id(value, redis_root)
-            else:
-                value = {
-                    'django_id': value
-                }
-
+            model_name = self.model.__name__
+            instance_id = value
+            value = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')[instance_id]
         return value
 
 
@@ -256,34 +237,18 @@ class RedisManyToMany(RedisList):
             self.value = get_ids_from_untyped_data(self.value)
         return super().clean()
 
-    def _get_instance_by_id(self, id, redis_root):
-        model_name = self.model.__name__
-        instance = {
-            'id': id
-        }
-        fast_get_results = redis_root.fast_get_keys_values(f'{redis_root.prefix}:{model_name}:{id}:*')
-        for key, raw_value in fast_get_results.items():
-            prefix, model_name, instance_id, field_name = key.split(':')
-            value = redis_root.deserialize_value(raw_value, model_name, field_name)
-            instance[field_name] = value
-        return instance
-
     def deserialize_value(self, value, redis_root):
         self.deserialize_value_check_null(value, redis_root)
         if value != 'null':
             value = super().deserialize_value(value, redis_root)
             check_types(value, list)
-            if self.save_related_models:
-                values_list = [
-                    self._get_instance_by_id(redis_model_instance_dict, redis_root)
-                    for redis_model_instance_dict in value
-                ]
-            else:
-                values_list = [
-                    {'django_id': django_id}
-                    for django_id in value
-                ]
-            value = values_list
+            model_name = self.model.__name__
+            isntances_ids = value
+            instances_list = []
+            for instance_id in isntances_ids:
+                instance = redis_root._get_instances_by_key(f'{redis_root.prefix}:{model_name}:{instance_id}')
+                instances_list.append(instance)
+            value = instances_list
         return value
 
 
@@ -857,21 +822,32 @@ class RedisRoot:
         allowed = all(allowed_list)
         return allowed
 
-    def _get_all_stored_model_instances(self, model, filters=None):
-        model_name = model.__name__
-        instances_with_allowed = {}
-        fast_get_results = self.fast_get_keys_values(f'{self.prefix}:{model_name}:*')
-        for instance_key, fields_json in fast_get_results.items():
+    def _get_instances_by_key(self, key):
+        raw_instances = self.fast_get_keys_values(key)
+        instances = {}
+        for instance_key, fields_json in raw_instances.items():
             prefix, model_name, instance_id = instance_key.split(':')
             instance_id = int(instance_id)
             fields_dict = json.loads(fields_json)
             for field_name, raw_value in fields_dict.items():
                 value = self.deserialize_value(raw_value, model_name, field_name)
-                allowed = self._filter_field_name(field_name, value, filters)
+                if instance_id not in instances.keys():
+                    instances[instance_id] = {}
+                instances[instance_id][field_name] = value
+        return instances
+
+
+    def _get_all_stored_model_instances(self, model, filters=None):
+        model_name = model.__name__
+        instances = self._get_instances_by_key(f'{self.prefix}:{model_name}:*')
+        instances_with_allowed = {}
+        for instance_id, instance_fields in instances.items():
+            for field_name, field_value in instance_fields.items():
+                allowed = self._filter_field_name(field_name, field_value, filters)
                 if instance_id not in instances_with_allowed.keys():
                     instances_with_allowed[instance_id] = {}
                 instances_with_allowed[instance_id][field_name] = {
-                    'value': value,
+                    'value': field_value,
                     'allowed': allowed
                 }
         return instances_with_allowed
@@ -921,12 +897,12 @@ class RedisRoot:
                 field_ttl = saved_model.get_field_ttl(field)
         return field_ttl
 
-    def _update_by_key(self, key, fields_to_update, renew_ttl, new_ttl):
+    def _update_by_instance_key(self, instance_key, fields_to_update, renew_ttl, new_ttl):
         updated_data = None
-        prefix, model_name, instance_id = key.split(':')
+        prefix, model_name, instance_id = instance_key.split(':')
         saved_model = self._get_registered_model_by_name(model_name)
         instance_id = int(instance_id)
-        instance_data_json = self.redis_instance.get(key)
+        instance_data_json = self.redis_instance.get(instance_key)
         instance_data = json.loads(instance_data_json)
         data_to_write = {}
         for field_name, field_data in instance_data.items():
@@ -936,9 +912,9 @@ class RedisRoot:
                 cleaned_value = saved_field_instance.clean()
             else:
                 cleaned_value = field_data
-            if key not in data_to_write.keys():
-                data_to_write[key] = {}
-            data_to_write[key][field_name] = cleaned_value
+            if instance_key not in data_to_write.keys():
+                data_to_write[instance_key] = {}
+            data_to_write[instance_key][field_name] = cleaned_value
         for instance_key, fields_to_write in data_to_write.items():
             ttl = None
             if renew_ttl:
@@ -958,14 +934,14 @@ class RedisRoot:
         updated_datas = []
         if instances is None:
             for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:*'):
-                updated_data = self._update_by_key(key, fields_to_update, renew_ttl, new_ttl)
+                updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                 if updated_data is not None:
                     updated_datas.append(updated_data)
         else:
             ids_to_update = get_ids_from_untyped_data(instances)
             for instance_id in ids_to_update:
                 for key in self.redis_instance.scan_iter(f'{self.prefix}:{model_name}:{instance_id}'):
-                    updated_data = self._update_by_key(key, fields_to_update, renew_ttl, new_ttl)
+                    updated_data = self._update_by_instance_key(key, fields_to_update, renew_ttl, new_ttl)
                     if updated_data is not None:
                         updated_datas.append(updated_data)
         updated_instances = {}
